@@ -21,29 +21,31 @@ SRVTYPE = 'open'
 EP = ''
 SYSVERSION = '1.3.0'
 
+##########################################
+#### pro
 # REAL ENV.
-KAISA_ROOT_URL = "kgl.jt00000.com"
+KAISA_ROOT_URL_REAL = "kgl.jt00000.com"
+#### sit
 KAISA_ROOT_URL_SIM = "sit-kgl.jt00000.com"
+
+KAISA_ROOT_URL = KAISA_ROOT_URL_SIM
+##########################################
+
 # KAISA_ROOT_URL = KAISA_ROOT_URL_SIM
 KAISA_ROOT_URL_API = "openapi.jt00000.com"
 
 # # AUTHENTICA_URL = "https://openapi.jt00000.com"
-## sit
-CRYPTO_RSA_URL = "https://sit-__kaisarooturl__/kgl-third-authorization/crypto/key/RSA"
+
 ## pro
-#CRYPTO_RSA_URL = "https://__kaisarooturl__/kgl-third-authorization/crypto/key/RSA"
+CRYPTO_RSA_URL = "https://__kaisarooturl__/kgl-third-authorization/crypto/key/RSA"
+
 ## pro
-#AUTHENTICA_URL = "https://__kaisarooturl__/kgl-third-authorization/oauth/token"
-## sit
-AUTHENTICA_URL = "https://sit-__kaisarooturl__/kgl-third-authorization/oauth/token"
-## userid-sit
-AU_USERID_URL = 'https://sit-__kaisarooturl__/kgl-user-center/userRegInfo/selectLoginUserInfo'
+AUTHENTICA_URL = "https://__kaisarooturl__/kgl-third-authorization/oauth/token"
+
 ## userid-pro
-#AU_USERID_URL = 'https://__kaisarooturl__/kgl-user-center/userRegInfo/selectLoginUserInfo'
+AU_USERID_URL = 'https://__kaisarooturl__/kgl-user-center/userRegInfo/selectLoginUserInfo'
 QUOTE_URL = "https://kgl.jt00000.com/hq"
 
-# WEBSOCKET_DATA_HOST = "ws://__kaisarooturl__/dz_app_ws/ws"
-WEBSOCKET_DATA_HOST = "ws://sit-kgl.jt00000.com/dz_app_ws/ws"
 REST_DATA_HOST = "https://__kaisarooturl__/dzApp/dzHttpApi"
 
 TRADE_CRYPTO_RSA_URL = "https://__kaisarooturl__/kgl-trade-service/crypto/key/RSA"
@@ -53,29 +55,23 @@ WEBSOCKET_TRADE_HOST = "wss://__kaisarooturl__/kgl-trade-push-service/ws"
 
 openapi_scope = "wthk"
 openapi_scope = "read"
-# < 2120-04-07 => "https://sit-kgl.jt00000.com/kgl-stock-push-provider"
-# > 2120-04-07 => https://sit-kgl.jt00000.com/kgl-stock-support-provider
-#
-MARKET_POST_URL = "https://sit-kgl.jt00000.com/kgl-stock-support-provider"
-# 实时行情接口URL
-MARKET_WS_URL = "ws://sit-stock-gateway.jt00000.com/stock-front/stock"   #"ws://uat-stock.jt00000.com/stock"
 
 # 港股tick历史数据URL
-HK_STOCK_TICK_POST_URL = 'https://sit-kgl.jt00000.com/kgl-stock-support-provider/stock/quote/tickHistory/v2'
+HK_STOCK_TICK_POST_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/stock/quote/tickHistory/v2'
 # 港股KLine历史数据URL
-HK_STOCK_KLINE_POST_URL = 'https://sit-kgl.jt00000.com/kgl-stock-support-provider/quoteInfo/kLineHistory/v2'
+HK_STOCK_KLINE_POST_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/kLineHistory/v2'
 # 港股盘口十档历史数据URL
-HK_STOCK_LEVEL2_10_ORDER_URL = 'https://sit-kgl.jt00000.com/kgl-stock-support-provider/quoteInfo/orderBuySellHisList/v2'
+HK_STOCK_LEVEL2_10_ORDER_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/orderBuySellHisList/v2'
 # 港股经纪人历史数据URL
-HK_STOCK_BROKER_URL = 'https://sit-kgl.jt00000.com/kgl-stock-support-provider/quoteInfo/brokerHisList/v2'
+HK_STOCK_BROKER_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/brokerHisList/v2'  # sit-kgl.jt00000.com
 
 
 # 基础财务指标URL, Post
-BASIC_FIN_POST_URL = "https://sit-kgl.jt00000.com/kgl-glidata-center/stockReport/finReport"
+BASIC_FIN_POST_URL = "https://__kaisarooturl__/kgl-glidata-center/stockReport/finReport"
 # 衍生财务指标URL，Post
-EX_FIN_POST_URL = "http://sit-kgl.jt00000.com/kgl-stock-front-stoacq/openapi/financial/factor"
+EX_FIN_POST_URL = "http://__kaisarooturl__/kgl-stock-front-stoacq/openapi/financial/factor"
 # 基础/衍生技术面因子URL，Post
-BE_TECH_POST_URL = "http://sit-kgl.jt00000.com/kgl-stock-front-stoacq/openapi/stock/techindex"
+BE_TECH_POST_URL = "http://__kaisarooturl__/kgl-stock-front-stoacq/openapi/stock/techindex"
 
 START_PUSH = 200
 STOP_PUSH = 201
